<?php

/**
 * WP HTML5 Outliner: Outline class
 * 
 * @package WP_HTML5_Outliner
 * @since   1.0.0
 */

namespace wph5o;

/**
 * Represents an outline generated by the Document Outline Algorithm.
 * 
 * An Outline instance corresponds to a sectioning element. If the element
 * is a body element, the outline covers an entire HTML document, i.e., the 
 * outline is a document outline.
 * 
 * @since 1.0.0
 */
class Outline {

	/**
	 * Represents the element for which the outline is created. 
	 * 
	 * @since 1.0.0
	 * @var   object 
	 */
	private $owner;

	/**
	 * Represents the sections of the outline.
	 * 
	 * @since 1.0.0
	 * @var   array
	 */
	private $sections;

	/**
	 * Initializes a new Outline.
	 * 
	 * @since 1.0.0
	 * @param object $owner the element for which the outline is created
	 * @param object $section a Section instance
	 */
	public function __construct( $owner, $section ) {

		$this->owner 	= $owner;
		$this->sections = array( $section );

	}

	/**
	 * Gets the sections of the outline.
	 * 
	 * @since  1.0.0
	 * @return array Returns the outline sections.
	 */
	public function get_sections() {

		return $this->sections;

	}

	/**
	 * Adds a section to the outline.
	 * 
	 * @param object $section a Section instance
	 */
	public function append_section( $section ) {

		$this->sections[] = $section;

	}

} // END class Outline